OC.L10N.register(
    "spreed",
    {
    "a conversation" : "saruna",
    "(Duration %s)" : "(Ilgums %s)",
    "You attended a call with {user1}" : "Jūs piedalījāties sarunā ar {user1}",
    "_%n guest_::_%n guests_" : ["%n viesi","%n viesi","%n viesi"],
    "You attended a call with {user1} and {user2}" : "Jūs piedalījāties sarunā ar {user1} un {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Jūs piedalījāties sarunā ar {user1}, {user2} un {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Jūs piedalījāties sarunā ar {user1}, {user2}, {user3} un {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Jūs piedalījāties sarunā ar {user1}, {user2}, {user3}, {user4} un {user5}",
    "_%n other_::_%n others_" : ["%n other","%n cits","%n citi"],
    "{actor} invited you to {call}" : "{actor} uzaicināja jūs uz {call}",
    "Talk" : "Runāt",
    "Guest" : "Viesis",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Viens pret vienu sarunas tagad ir pastāvīgas, un tās vairs nevar nejauši pārveidot par kopu sarunām. Kā arī, kad viens no dalībniekiem pamet sarunu, tā vairs netiek automātiski izdzēsta. Tikai ja abi dalībnieki izies, saruna tiks izdzēsta no servera",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Sānu joslā tagad var atrast pēdējo kopīgoto vienumu pārskatu",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Sapulces uzlabotas ar viesu, kuri uzaicināti e-pastā, atpazīšanu, dalībnieku saraksta ievietošanu, aptauju melnraksti un dalībnieku sarakstu lejupielādēšanu.",
    "Talk updates ✅" : "Talk atjauninājumi ✅",
    "{actor} created the conversation" : "{actor} izveidoja sarunu",
    "You created the conversation" : "Tu izveidoji sarunu",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pārdēvējāt sarunu no \"%1$s\" uz \"%2$s\"",
    "You started a call" : "Jūs sākāt zvanu",
    "{actor} started a call" : "{actor} sācis zvanu",
    "{actor} joined the call" : "{actor} pievienojies zvanam",
    "You joined the call" : "Jūs pievienojaties zvanam",
    "{actor} left the call" : "{actor} pameta zvanu",
    "You left the call" : "Tu pameti zvanu",
    "{actor} unlocked the conversation" : "{actor} atslēdz sarunu",
    "You unlocked the conversation" : "Jūs atslēdzāt sarunu",
    "{actor} locked the conversation" : "{actor} bloķē sarunu",
    "You locked the conversation" : "Jūs bloķējāt sarunu",
    "{actor} allowed guests" : "{actor} atļauj viesus",
    "You allowed guests" : "Jūs atļaujat viesus",
    "{actor} disallowed guests" : "{actor} nepieļāva viesus",
    "You disallowed guests" : "Jūs nepieļāvāt viesus",
    "{actor} set a password" : "{actor} iestatīja paroli",
    "You set a password" : "Jūs iestatījāt paroli",
    "{actor} removed the password" : "{actor} noņēma paroli",
    "You removed the password" : "Jūs noņēmāt paroli",
    "{actor} added {user}" : "{actor} pievienoja {user}",
    "You joined the conversation" : "Jūs pievienojaties sarunai",
    "{actor} joined the conversation" : "{actor} pievienojās sarunai",
    "You added {user}" : "Tu pievienoji {user}",
    "{actor} added you" : "{actor} jūs pievienoja",
    "You left the conversation" : "Tu pameti sarunu",
    "{actor} left the conversation" : "{actor} pameta sarunu",
    "{actor} removed {user}" : "{actor} noņēma {user}",
    "You removed {user}" : "Jūs noņēmāt {user}",
    "{actor} removed you" : "{actor} jūs noņēma",
    "You added {phone}" : "Tu pievienoji {phone}",
    "{actor} promoted {user} to moderator" : "{actor} paaugstināja {user} par regulētāju",
    "You promoted {user} to moderator" : "Jūs paaugstinājāt {user} par regulētāju",
    "{actor} promoted you to moderator" : "{actor} paaugstināja jūs par regulētāju",
    "{actor} demoted {user} from moderator" : "{actor} pazemināts {user} no regulētāja",
    "You demoted {user} from moderator" : "Jūs pazeminājāt {user} no regulētāja",
    "{actor} demoted you from moderator" : "{actor} pazemināja jūs no regulētāja",
    "{actor} shared a file which is no longer available" : "{actor} kopīgoja datni, kas vairs nav pieejama",
    "You shared a file which is no longer available" : "Jūs kopīgojāt datni, kas vairs nav pieejama",
    "Message deleted by author" : "Ziņojumu izdzēsa autors",
    "Administration" : "Pārvaldīšana",
    "System" : "Sistēma",
    "%s (guest)" : "%s (viesis)",
    "Talk conversations" : "Sarunas",
    "Talk to %s" : "Runāt ar %s",
    "File is not shared, or shared but not with the user" : "Datne nav koplietota vai koplietots, bet nav koplietots ar lietotāju",
    "File is too big" : "Datne ir par lielu",
    "Invalid file provided" : "Norādīta nederīga datne",
    "Invalid image" : "Nederīgs attēls",
    "Unknown filetype" : "Nezināms datnes veids",
    "Talk mentions" : "Pieminēšana Talk",
    "More conversations" : "Vairāk sarunu",
    "Say hi to your friends and colleagues!" : "Sasveicinies ar saviem draugiem un kolēģiem!",
    "No unread mentions" : "Nav nelasītu pieminēšanu",
    "Conversation invitation" : "Sarunas uzaicinājums",
    "Description" : "Apraksts",
    "Password request: %s" : "Paroles pieprasījums: %s",
    "Private conversation" : "Privāta saruna",
    "Dismiss notification" : "Noraidīt paziņojumu",
    "Accept" : "Pieņemt",
    "Decline" : "Noraidīt",
    "New message" : "Jauna ziņa",
    "Reminder" : "Atgādinājums",
    "{user} sent you a private message" : "{user} nosūtīja jums privātu ziņojumu",
    "{user} sent a message in conversation {call}" : "{user} nosūtīja ziņu sarunā {call}",
    "A deleted user sent a message in conversation {call}" : "Izdzēsts lietotājs nosūtīja ziņojumu sarunā {call}",
    "A guest sent a message in conversation {call}" : "Viesis nosūtījis ziņojumu sarunā {call}",
    "{user} mentioned you in a private conversation" : "{user} tevi pieminēja privātā sarunā",
    "{user} mentioned you in conversation {call}" : "{user} pieminēja jūs sarunā {call}",
    "A deleted user mentioned you in conversation {call}" : "Izdzēsts lietotājs pieminēja Tevi sarunā {call}",
    "A guest mentioned you in conversation {call}" : "Kāds viesis jūs pieminēja sarunā {call}",
    "{user} invited you to a group conversation: {call}" : "{user} uzaicināja jūs uz grupas sarunu: {call}",
    "Join call" : "Pievienoties zvanam",
    "{user} would like to talk with you" : "{user} vēlas runāt ar Tevi",
    "A group call has started in {call}" : "Grupas zvans ir sācies {call}",
    "Open settings" : "Atvērt iestatījumus",
    "error" : "kļūda",
    "Open Talk" : "Atvērt Talk",
    "Avatar image is not square" : "Avatar attēls nav kvadrāts",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nepareizi uzvedās. Lūgums atgriezties vēlāk.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nav sasniedzams. Lūgums atgriezties vēlāk.",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Apvienotie Arābu Emirāti",
    "Afghanistan" : "Afganistāna",
    "Antigua and Barbuda" : "Antigva un Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albānija",
    "Armenia" : "Armēnija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentīna",
    "American Samoa" : "Amerikas Samoa",
    "Austria" : "Austija",
    "Australia" : "Austrālija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ālandu salas",
    "Azerbaijan" : "Azerbaidžāna",
    "Bosnia and Herzegovina" : "Bosnija un Hercogovina",
    "Barbados" : "Barbadosa",
    "Bangladesh" : "Bangladeša",
    "Belgium" : "Beļģija",
    "Burkina Faso" : "Burkinafaso",
    "Bulgaria" : "Bulgārija",
    "Bahrain" : "Bahreina",
    "Burundi" : "Burundija",
    "Benin" : "Benina",
    "Saint Barthélemy" : "Senbartelmī",
    "Bermuda" : "Bermudu salas",
    "Brunei Darussalam" : "Bruneja Darusalama",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sintēstatiusa un Saba",
    "Brazil" : "Brazīlija",
    "Bahamas" : "Bahamu salas",
    "Bhutan" : "Butāna",
    "Bouvet Island" : "Buvē sala",
    "Botswana" : "Botsvāna",
    "Belarus" : "Baltkrievija",
    "Belize" : "Beliza",
    "Canada" : "Kanāda",
    "Cocos (Keeling) Islands" : "Kokosu (Kīlinga) Salas",
    "Central African Republic" : "Centrālāfrikas Republika",
    "Congo" : "Kongo Republika",
    "Switzerland" : "Šveice",
    "Côte d'Ivoire" : "Kotdivuāra",
    "Cook Islands" : "Kuka salas",
    "Chile" : "Čīle",
    "Cameroon" : "Kamerūna",
    "China" : "Ķīna",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kaboverde",
    "Curaçao" : "Kirasao",
    "Christmas Island" : "Ziemassvētku sala",
    "Cyprus" : "Ķipra",
    "Czechia" : "Čehija",
    "Germany" : "Vācija",
    "Djibouti" : "Džibutija",
    "Denmark" : "Dānija",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikānas Republika",
    "Algeria" : "Alžīrija",
    "Ecuador" : "Ekvadora",
    "Estonia" : "Igaunija",
    "Egypt" : "Ēģipte",
    "Western Sahara" : "Rietumsahāra",
    "Eritrea" : "Eritreja",
    "Spain" : "Spānija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Somija",
    "Fiji" : "Fidži",
    "Falkland Islands (Malvinas)" : "Folklenda salas (Malvinas)",
    "Faroe Islands" : "Fēru salas",
    "France" : "Francija",
    "Gabon" : "Gabona",
    "United Kingdom of Great Britain and Northern Ireland" : "Lielbritānijas un Ziemeļīrijas Apvienotā Karaliste",
    "Grenada" : "Grenādā",
    "Georgia" : "Gruzija",
    "French Guiana" : "Franču Gviāna",
    "Guernsey" : "Gērnsija",
    "Ghana" : "Gana",
    "Gibraltar" : "Ģibraltārs",
    "Greenland" : "Grīnlande",
    "Gambia" : "Gambija",
    "Guinea" : "Gvineja",
    "Guadeloupe" : "Gvadelupa",
    "Equatorial Guinea" : "Ekvatoriālā Gvineja",
    "Greece" : "Grieķija",
    "South Georgia and the South Sandwich Islands" : "Dienviddžordžija un Dienvidsendviču salas",
    "Guatemala" : "Gvatemala",
    "Guam" : "Guama",
    "Guinea-Bissau" : "Gvineja-Bisava",
    "Guyana" : "Gajana",
    "Hong Kong" : "Honkonga",
    "Heard Island and McDonald Islands" : "Hērda Sala un Makdonalda Salas",
    "Honduras" : "Hondurasa",
    "Croatia" : "Horvātija",
    "Haiti" : "Haiti",
    "Hungary" : "Ungārija",
    "Indonesia" : "Indonēzija",
    "Ireland" : "Īrija",
    "Israel" : "Izraēla",
    "Isle of Man" : "Menas sala",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Britu Indijas Okeāna Teritorija",
    "Iraq" : "Irāka",
    "Iceland" : "Islande",
    "Italy" : "Itālija",
    "Jersey" : "Džērsija",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordānija",
    "Japan" : "Japāna",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizstāna",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komoras",
    "Saint Kitts and Nevis" : "Sentkitsa un Nevisa",
    "Kuwait" : "Kuveita",
    "Cayman Islands" : "Kaimanu Salas",
    "Kazakhstan" : "Kazahstāna",
    "Lao People's Democratic Republic" : "Laosas Tautas Demokrātiskā Republika",
    "Lebanon" : "Lebanona",
    "Saint Lucia" : "Sentlūsija",
    "Liechtenstein" : "Lihtenšteina",
    "Sri Lanka" : "Šrilanka",
    "Liberia" : "Libērija",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lietuve",
    "Luxembourg" : "Luksemburga",
    "Latvia" : "Latvija",
    "Libya" : "Lībija",
    "Morocco" : "Maroka",
    "Monaco" : "Monako",
    "Montenegro" : "Melnkalne",
    "Saint Martin (French part)" : "Senmartēna (Francijas teritorija)",
    "Madagascar" : "Madagaskāra",
    "Marshall Islands" : "Māršala salas",
    "Mali" : "Mali",
    "Myanmar" : "Činlande",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Ziemeļu Marianas salas",
    "Martinique" : "Martinika",
    "Mauritania" : "Mauritānija",
    "Montserrat" : "Montserrata",
    "Malta" : "Malta",
    "Mauritius" : "Maurīcija",
    "Maldives" : "Maldīvu salas",
    "Malawi" : "Malāvija",
    "Mexico" : "Meksika",
    "Malaysia" : "Malaizija",
    "Mozambique" : "Mozambika",
    "Namibia" : "Namībija",
    "New Caledonia" : "Jaunkaledonija",
    "Niger" : "Nigēra",
    "Norfolk Island" : "Norfolkas sala",
    "Nigeria" : "Nigērija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nīderlande",
    "Norway" : "Norvēģija",
    "Nepal" : "Nepāla",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Jaunzēlande",
    "Oman" : "Omāna",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Franču Polinēzija",
    "Papua New Guinea" : "Papua-Jaungvineja",
    "Philippines" : "Filipīnas",
    "Pakistan" : "Paķistāna",
    "Poland" : "Polija",
    "Saint Pierre and Miquelon" : "Senpjēra un Mikelona",
    "Pitcairn" : "Pitkērna",
    "Puerto Rico" : "Puertoriko",
    "Palestine, State of" : "Palestīna",
    "Portugal" : "Portugāle",
    "Palau" : "Palau",
    "Paraguay" : "Paragvaja",
    "Qatar" : "Katāra",
    "Réunion" : "Reinjona",
    "Romania" : "Rumānija",
    "Serbia" : "Serbija",
    "Russian Federation" : "Krievijas Federācija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saūda Arābija",
    "Solomon Islands" : "Zālamana salas",
    "Seychelles" : "Seišelas",
    "Sudan" : "Sudāna",
    "Sweden" : "Zviedrija",
    "Singapore" : "Singapūra",
    "Saint Helena, Ascension and Tristan da Cunha" : "Svētās Helēnas sala, Debesbraukšanas sala un Tristana da Kuņas salas",
    "Slovenia" : "Slovēnija",
    "Svalbard and Jan Mayen" : "Svalbārai un Jana Majena",
    "Slovakia" : "Slovākija",
    "Sierra Leone" : "Sjerraleone",
    "San Marino" : "Sanmarīno",
    "Senegal" : "Senegāla",
    "Somalia" : "Somālija",
    "Suriname" : "Surinama",
    "South Sudan" : "Dienvidsudāna",
    "Sao Tome and Principe" : "Santome un Prinsipi",
    "El Salvador" : "Salvadora",
    "Sint Maarten (Dutch part)" : "Sintmārtena (Nīderlandes teritorija)",
    "Syrian Arab Republic" : "Sīrijas Republika",
    "Turks and Caicos Islands" : "Tērksas un Kaikosas salas",
    "Chad" : "Čada",
    "French Southern Territories" : "Francijas Dienvidjūru Zemes",
    "Togo" : "Togo",
    "Thailand" : "Taizeme",
    "Tajikistan" : "Tadžikistāna",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Austrumtimora",
    "Turkmenistan" : "Turkmenistāna",
    "Tunisia" : "Tunisija",
    "Tonga" : "Tonga",
    "Turkey" : "Turcija",
    "Trinidad and Tobago" : "Trinidāda un Tobāgo",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzānija, Apvienotā Republika",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "ASV Mazās aizjūras salas",
    "United States of America" : "Amerikas Savienotās Valstis",
    "Uruguay" : "Urugvaja",
    "Uzbekistan" : "Uzbekistāna",
    "Holy See" : "Vatikāns",
    "Saint Vincent and the Grenadines" : "Sentvinsenta un Grenadīnas",
    "Viet Nam" : "Vjetnama",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Volisa un Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemena",
    "Mayotte" : "Majota",
    "South Africa" : "Dienvidāfrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabve",
    "Federation" : "Federācija",
    "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
    "Conversation not found" : "Saruna nav atrasta",
    "Chat, video & audio-conferencing using WebRTC" : "Video un audio konferences, izmantojot WebRTC",
    "Leave call" : "Pamest zvanu",
    "Request password" : "Pieprasīt paroli",
    "Error requesting the password." : "Kļūda, pieprasot paroli.",
    "This conversation has ended" : "Šī saruna ir beigusies",
    "Everyone" : "Visi",
    "Save changes" : "Saglabāt izmaiņas",
    "Saving …" : "Saglabā ...",
    "Saved!" : "Saglabāts!",
    "Limit to groups" : "Grupu ierobežojums",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ja ir atlasīta vismaz viena grupa, tikai cilvēki no sarakstā uzskaitītajām grupām var piedalīties sarunās.",
    "Guests can still join public conversations." : "Viesi joprojām var pievienoties publiskām sarunām.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Lietotāji, kas vairs nevar izmantot Talk, joprojām tiks uzrādīti kā dalībnieki viņu iepriekšējās sarunās, kā arī tiks paturētas viņu ziņas.",
    "Enabled" : "Iespējots",
    "Disabled" : "Atspējots",
    "State" : "Stāvoklis",
    "Name" : "Nosaukums",
    "Beta" : "Beta",
    "Permissions" : "Atļaujas",
    "General settings" : "Vispārīgie iestatījumi",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "Pending" : "Gaida",
    "Error" : "Kļūda",
    "Language" : "Valoda",
    "Country" : "Valsts",
    "Status" : "Status",
    "Created at" : "Izveidots plkst.",
    "Validate SSL certificate" : "Pārbaudīt SSL sertifikātu",
    "Delete this server" : "Izdzēst šo serveri",
    "Test this server" : "Testēt šo serveri",
    "Shared secret" : "Koplietojams noslēpums",
    "STUN server URL" : "STUN servera URL",
    "STUN servers" : "STUN serveris",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN serveris tiek izmantots, lai noteiktu maršrutētāja dalībnieku publisko IP adresi.",
    "TURN server URL" : "TURN servera URL",
    "TURN server secret" : "TURN servera noslēpums",
    "TURN server protocols" : "TURN servera protokols",
    "TURN servers" : "TURN serveris",
    "Failed" : "Neizdevās",
    "OK" : "Labi",
    "Confirm" : "Apstiprināt",
    "Reset" : "Atiestatīt",
    "Back" : "Atpakaļ",
    "Cancel" : "Atcelt",
    "Loading …" : "Ielādē…",
    "From" : "No",
    "To" : "Līdz",
    "Calendar" : "Kalendārs",
    "Attendees" : "Apmeklētāji",
    "Save" : "Saglabāt",
    "No results" : "Nav iznākuma",
    "Done" : "Pabeigts",
    "Waiting for others to join the call …" : "Gaidot citus pievienoties zvanam …",
    "You can invite others in the participant tab of the sidebar" : "Sānjoslā, dalībnieku cilnē var uzaicināt citus dalībniekus",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Sānjoslas dalībnieku cilnē varat uzaicināt citus lietotājus vai kopīgot šo saiti, lai uzaicinātu citus.",
    "Share this link to invite others!" : "Kopīgojiet šo saiti, lai uzaicinātu citus!",
    "Copy link" : "Kopēt saiti",
    "Mute audio" : "Izslēgt audio skaņu",
    "Disable video" : "Atspējot video",
    "Enable video" : "Iespējot video",
    "You" : "Jūs",
    "Show screen" : "Rādīt ekrānu",
    "Collapse" : "Sakļaut",
    "Favorite" : "Izlasē",
    "Date:" : "Datums:",
    "Hide details" : "Slēpt detaļas",
    "Show details" : "Rādīt informāciju",
    "Disable" : "Deaktivēt",
    "Enable" : "Iespējot",
    "Choose" : "Izvēlēties",
    "The file must be a PNG or JPG" : "Datnei jābūt PNG vai JPG",
    "Restricted" : "Ierobežota",
    "Meeting" : "Tikšanās",
    "Personal" : "Personīgs",
    "Setup overview" : "Uzstādīšanas pārskats",
    "Leave conversation" : "Atstāt sarunu",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
    "No" : "Nē",
    "Yes" : "Jā",
    "Delete conversation" : "Izdzēst sarunu",
    "_%n hour_::_%n hours_" : ["%n stundu","%n stunda","%n stundas"],
    "Password protection" : "Password protection",
    "Open conversation" : "Atvērt sarunu",
    "Edit" : "Labot",
    "Delete" : "Izdzēst",
    "Notifications" : "Paziņojumi",
    "Join" : "Pievienoties",
    "Create and copy link" : "Izveidot saiti un ievietot starpliktuvē",
    "Log in" : "Pieteikties",
    "Remove from favorites" : "Noņemt no izlases",
    "Add to favorites" : "Pievienot izlasei",
    "You need to promote a new moderator before you can leave the conversation." : "Pirms sarunas atstāšanas ir jāieceļ jauns regulētājs.",
    "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
    "Clear filter" : "Notīrīt atlasi",
    "Users" : "Lietotāji",
    "Groups" : "Grupas",
    "Open conversations" : "Atvērt sarunas",
    "None" : "Nav",
    "Devices" : "Ierīces",
    "No audio" : "Nav audio",
    "Invalid path selected" : "Atlasīts nederīgs ceļš",
    "Upload" : "Augšupielādēt",
    "Files" : "Datnes",
    "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
    "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien",
    "Reply" : "Atbildēt",
    "Go to file" : "Doties uz datni",
    "Translate" : "Tulkot",
    "Dismiss" : "Atmest",
    "Contact" : "Kontakts",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "File to share" : "Kopīgojamā datne",
    "Upload from device" : "Augšupielādēt no ierīces",
    "New file" : "Jauna datne",
    "Send" : "Sūtīt",
    "Settings" : "Iestatījumi",
    "moderator" : "moderators",
    "guest" : "viesis",
    "Remove participant" : "Noņemt dalībnieku",
    "Demote from moderator" : "Pazemināt no regulētāja",
    "Promote to moderator" : "Paaugstināt par regulētāju",
    "Remove" : "Izņemt",
    "Add users or groups" : "Add users or groups",
    "Searching …" : "Meklē...",
    "Participants" : "Dalībnieki",
    "Chat" : "Tērzēt",
    "Details" : "Detaļas",
    "From User" : "No lietotāja",
    "Load more results" : "Ielādēt vairāk iznākumu",
    "Projects" : "Projekti",
    "Link to a conversation" : "Saite uz sarunu",
    "Select conversation" : "Izvēlēties sarunu",
    "Error while setting read status privacy" : "Kļūda lasīšanas stāvokļa privātuma iestatīšanas laikā",
    "Error while setting typing status privacy" : "Kļūda rakstīšanas stāvokļa privātuma iestatīšanas laikā",
    "Appearance" : "Izskats",
    "Privacy" : "Privātums",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Search" : "Meklēt",
    "Start call" : "Sākt zvanu",
    "All tasks done!" : "Visi uzdevumi paveikti.",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} no %n uzdevumiem","{done} no %n uzdevuma","{done} no %n uzdevumiem"],
    "You are not allowed to enable screensharing" : "Nav ļauts iespējot ekrāna kopīgošanu",
    "No screensharing" : "Nav ekrāna kopīgošanas",
    "Screensharing options" : "Ekrāna kopīgošanas iespējas",
    "Enable screensharing" : "Iespējot ekrāna kopīgošanu",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrāna kopīgošanai ir nepieciešams lapu ielādēt ar HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
    "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Lai koplietotu ekrānu, lūdzu, izmantojiet citu pārlūkprogrammu, piemēram, Firefox vai Chrome.",
    "An error occurred while starting screensharing." : "Ekrāna kopīgošanas uzsākšanas laikā atgadījās kļūda.",
    "Show your screen" : "Rādīt savu ekrānu",
    "Stop screensharing" : "Apturēt ekrāna kopīgošanu",
    "Exit full screen (F)" : "Iziet no pilnekrāna (F)",
    "Grid view" : "Režģa izkārtojums",
    "Start recording" : "Uzsākt ierakstīšanu",
    "Open Calendar" : "Atvērt kalendāru",
    "Would you like to delete this conversation?" : "Vai izdzēst šo sarunu?",
    "Keep" : "Paturēt",
    "Select a region" : "Izvēlieties reģionu",
    "Submit" : "Iesniegt",
    "Duplicate session" : "Pavairot sesiju",
    "Join a conversation or start a new one" : "Pievienoties sarunai vai sākt jaunu",
    "User" : "Lietotājs",
    "Password" : "Parole",
    "API token" : "API pilnvara",
    "Login" : "Pieteikumvārds",
    "Nickname" : "Iesauka",
    "Client ID" : "Klienta ID",
    "Media" : "Informācijas nesēji",
    "Polls" : "Aptaujas",
    "Audio" : "Audio",
    "Other" : "Cits",
    "Show all polls" : "Parādīt visas aptaujas",
    "Group" : "Grupa",
    "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
    "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
    "Error while sharing file" : "Kļūda datnes kopīgošanā",
    "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
    "Default" : "Noklusējuma",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, restartējiet pārlūkprogrammu, jo ir audio un video kļūme",
    "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
    "Please move your setup to HTTPS" : "Lūdzu, pārvietojiet iestatījumu uz HTTPS",
    "Access to microphone & camera was denied" : "Tika noraidīta piekļuve mikrofonam un kamerai",
    "WebRTC is not supported in your browser" : "WebRTC netiek atbalstīta jūsu pārlūkprogrammā",
    "Please use a different browser like Firefox or Chrome" : "Lūdzu, izmantojiet citu pārlūkprogrammu, piemēram Firefox vai Chrome",
    "Error while accessing microphone & camera" : "Kļūda, piekļūstot mikrofonam un kamerai",
    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
    "%s Talk on your mobile devices" : "%s Sarunas mobilajās ierīcēs",
    "Android app" : "Android lietotne",
    "iOS app" : "iOS lietotne",
    "__language_name__" : "Latviešu",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Zvanu apkopojuma robotprogrammatūra izveido pārskata ziņojumu pēc zvana, uzskaitot visus dalībniekus un izklāstot uzdevumus",
    "Tasks" : "Uzdevumi",
    "Notes" : "Piezīmes",
    "Reports" : "Atskaites",
    "%s invited you to a conversation." : "%s uzaicināja jūs uz sarunu.",
    "You were invited to a conversation." : "Jūs uzaicinājāt uz sarunu.",
    "Click the button below to join." : "Noklikšķiniet uz tālāk esošās pogas, lai pievienotos.",
    "Join »%s«" : "Pievienoties »%s«",
    "{user} invited you to a private conversation" : "{user} uzaicināja jūs uz privātu sarunu",
    "Close" : "Aizvērt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
